---
name: Bug report
about: Found a bug in Pyzotero?
title: ''
labels: ''
assignees: urschrei

---

# Note
This issue tracker is for bug reports. Please don't ask about how to use the library here – the docs are comprehensive and include examples: https://pyzotero.readthedocs.io.

You can also ask questions on the forum: https://forums.zotero.org/discussions

# Reporting Bugs
If at all possible, provide a [MVCE](https://stackoverflow.com/help/minimal-reproducible-example). If this is inappropriate (e.g. it's obviously a bug), just fill in the below:

Platform:  
Python version:  
Pyzotero version: 

# Problem Description
- What were you trying to do?
    - What API call did it involve
    - What error was raised?

# More Details
If possible, paste the full traceback in a code block below, and fill in the summary
<details>
    <summary>Traceback</summary>
    
    code goes here, indented with four spaces

</details>
